==> 1.0.29.tar.gz: lib/webrtc/one_to_one_state.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:transmedika_one_to_one_call/webrtc/fcm.dart';
import 'package:transmedika_one_to_one_call/webrtc/profile.dart';
import 'package:transmedika_one_to_one_call/webrtc/registration_session.dart';

import 'socket_state.dart';

/// enum call state ///
enum CallState{
  registering,
  registerAccepted,
  registerRejected,
  notifyMe,
  callAccepted,
  callRejected,
  incomingCall,
  startCommunication,
  iceCandidate,
  stopCommunication,
  unknown,
  callAcceptedByUser,
  callRejectedByUser,
  missedCall,
  callingAccepted,
  callingRejected,
}

/// ui state ///
class OneToOneUiState extends Equatable{
  const OneToOneUiState({
    this.socketState,
    this.callState,
    this.localStream,
    this.remoteStream,
    this.removeRemoteStream,
    this.from,
    this.to,
    this.isCalling,
    this.registrationSessionFrom,
    this.registrationSessionTo,
    this.consultationId,
    this.mySelf,
    this.other,
    this.mute = false,
    this.frontCamera = true,
    this.enableVideo = true,
    this.fcm
  });

  final SocketState? socketState;
  final CallState? callState;
  final MediaStream? localStream;
  final MediaStream? remoteStream;
  final MediaStream? removeRemoteStream;
  final String? from;
  final String? to;
  final bool? isCalling;
  final RegistrationSession? registrationSessionFrom;
  final RegistrationSession? registrationSessionTo;
  final String? consultationId;
  final Profile? mySelf;
  final Profile? other;
  final bool? mute;
  final bool? frontCamera;
  final bool? enableVideo;
  final Fcm? fcm;

  OneToOneUiState copyWith({
    SocketState? socketState,
    CallState? callState,
    MediaStream? localStream,
    MediaStream? remoteStream,
    MediaStream? removeRemoteStream,
    String? from,
    String? to,
    bool? isCalling,
    RegistrationSession? registrationSessionFrom,
    RegistrationSession? registrationSessionTo,
    String? consultationId,
    Profile? mySelf,
    Profile? other,
    bool? mute,
    bool? frontCamera,
    bool? enableVideo,
    Fcm? fcm
  }) {
    return OneToOneUiState(
      socketState: socketState ?? this.socketState,
      callState: callState ?? this.callState,
      localStream: localStream ?? this.localStream,
      remoteStream: remoteStream ?? this.remoteStream,
      removeRemoteStream: removeRemoteStream ?? this.removeRemoteStream,
      from: from ?? this.from,
      to: to ?? this.to,
      isCalling: isCalling ?? this.isCalling,
      registrationSessionFrom: registrationSessionFrom ?? this.registrationSessionFrom,
      registrationSessionTo: registrationSessionTo ?? this.registrationSessionTo,
      consultationId: consultationId ?? this.consultationId,
      mySelf: mySelf ?? this.mySelf,
      other: other ?? this.other,
      mute: mute ?? this.mute,
      frontCamera: frontCamera ?? this.frontCamera,
      enableVideo: enableVideo ?? this.enableVideo,
      fcm: fcm ?? this.fcm
    );
  }

  @override
  List<Object?> get props => [
    socketState, callState, localStream,
    remoteStream, removeRemoteStream, from,
    to, isCalling, registrationSessionFrom,
    registrationSessionTo, consultationId,
    mySelf, other, mute, frontCamera, enableVideo, fcm
  ];
}

==> 1.0.31.tar.gz: lib/webrtc/one_to_one_state.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:transmedika_one_to_one_call/webrtc/fcm.dart';
import 'package:transmedika_one_to_one_call/webrtc/profile.dart';
import 'package:transmedika_one_to_one_call/webrtc/registration_session.dart';

import 'socket_state.dart';

/// enum call state ///
enum CallState{
  registering,
  registerAccepted,
  registerRejected,
  notifyMe,
  callAccepted,
  callRejected,
  incomingCall,
  startCommunication,
  iceCandidate,
  stopCommunication,
  unknown,
  callAcceptedByUser,
  callRejectedByUser,
  missedCall,
  callingAccepted,
  callingRejected,
}

enum VideoSource {
  camera,
  screen,
}

/// ui state ///
class OneToOneUiState extends Equatable{
  const OneToOneUiState({
    this.socketState,
    this.callState,
    this.localStream,
    this.remoteStream,
    this.removeRemoteStream,
    this.from,
    this.to,
    this.isCalling,
    this.registrationSessionFrom,
    this.registrationSessionTo,
    this.consultationId,
    this.mySelf,
    this.other,
    this.mute = false,
    this.frontCamera = true,
    this.enableVideo = true,
    this.fcm,
    this.videoSource = VideoSource.camera,
    this.swapScreen = false,
  });

  final SocketState? socketState;
  final CallState? callState;
  final MediaStream? localStream;
  final MediaStream? remoteStream;
  final MediaStream? removeRemoteStream;
  final String? from;
  final String? to;
  final bool? isCalling;
  final RegistrationSession? registrationSessionFrom;
  final RegistrationSession? registrationSessionTo;
  final String? consultationId;
  final Profile? mySelf;
  final Profile? other;
  final bool? mute;
  final bool? frontCamera;
  final bool? enableVideo;
  final Fcm? fcm;
  final VideoSource? videoSource;
  final bool? swapScreen;

  OneToOneUiState copyWith({
    SocketState? socketState,
    CallState? callState,
    MediaStream? localStream,
    MediaStream? remoteStream,
    MediaStream? removeRemoteStream,
    String? from,
    String? to,
    bool? isCalling,
    RegistrationSession? registrationSessionFrom,
    RegistrationSession? registrationSessionTo,
    String? consultationId,
    Profile? mySelf,
    Profile? other,
    bool? mute,
    bool? frontCamera,
    bool? enableVideo,
    Fcm? fcm,
    VideoSource? videoSource,
    bool? swapScreen,
  }) {
    return OneToOneUiState(
      socketState: socketState ?? this.socketState,
      callState: callState ?? this.callState,
      localStream: localStream ?? this.localStream,
      remoteStream: remoteStream ?? this.remoteStream,
      removeRemoteStream: removeRemoteStream ?? this.removeRemoteStream,
      from: from ?? this.from,
      to: to ?? this.to,
      isCalling: isCalling ?? this.isCalling,
      registrationSessionFrom: registrationSessionFrom ?? this.registrationSessionFrom,
      registrationSessionTo: registrationSessionTo ?? this.registrationSessionTo,
      consultationId: consultationId ?? this.consultationId,
      mySelf: mySelf ?? this.mySelf,
      other: other ?? this.other,
      mute: mute ?? this.mute,
      frontCamera: frontCamera ?? this.frontCamera,
      enableVideo: enableVideo ?? this.enableVideo,
      fcm: fcm ?? this.fcm,
      videoSource: videoSource ?? this.videoSource,
      swapScreen: swapScreen ?? this.swapScreen
    );
  }

  @override
  List<Object?> get props => [
    socketState, callState, localStream,
    remoteStream, removeRemoteStream, from,
    to, isCalling, registrationSessionFrom,
    registrationSessionTo, consultationId,
    mySelf, other, mute, frontCamera, enableVideo, fcm, videoSource, swapScreen
  ];
}
